#!/usr/bin/env python3

# This amulet test deploys the bundles.yaml file in this directory.

import os
import unittest
import yaml
import amulet
import sys

seconds_to_wait = 1000


class BundleTest(unittest.TestCase):
    """ Create a class for testing the charm in the unit test framework. """
    @classmethod
    def setUpClass(cls):
        """ Set up an amulet deployment using the bundle. """
        d = amulet.Deployment()
        # We have a contextual test, if no config is present, initialze the
        # test with an empty configuration set
        config = {}
        local_path = os.path.join(os.path.dirname(__file__), 'local.yaml')
        with open(local_path, "r") as fd:
           config = yaml.safe_load(fd)

        url = config.get('db2').get('db2_url')
        print('Using URL  %s' % url)
        # Test if a DB2 url for the repository is defined
        if not url:
            print("You need to define a url for the DB2 packages repository.\n"
              "Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

        pkg = config.get('db2').get('db2_package')
        print('Using DB2 package %s' % pkg)
        if not pkg:
            print("You need to define a package name for IBM DB2.\n"
              "Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

        bundle_path = os.path.join(os.path.dirname(__file__), 'bundles.yaml')
        with open(bundle_path, 'r') as bundle_file:
            contents = yaml.safe_load(bundle_file)
            d.load(contents)

        # Software doesn't actually install until you accept the license
        d.configure('db2', { 'accept-ibm-db2-license': True, 'db2_url': url, 'db2_package_name' : pkg })

        d.setup(seconds_to_wait)
        d.sentry.wait(seconds_to_wait)
        cls.d = d

    def test_deployed(self):
        """ Test to see if the bundle deployed successfully. """
        self.assertTrue(self.d.deployed)

        db2_unit = self.d.sentry.unit['db2/0']
        # Get the port num where db2 is running and check for netstat
        output, code = db2_unit.run("su - db2inst1 -c 'db2 get dbm cfg' | grep -i svce | cut -d'=' -f2")
        if code != 0:
          message = 'Unable to get the port number where DB2 is running. Exiting before completing rest of the verification tests.'
          amulet.raise_status(amulet.FAIL, msg=message)
        print('DB2 running in port num : %s' % output)
        print('Checking netstat comamnd')
        cmd = "su - db2inst1 -c 'netstat -an' | grep LISTEN | grep %s" % output
        output, code = db2_unit.run(cmd)
        if code != 0:
         message = 'Unable to get the port number where DB2 is running. Exiting before completing rest of the verification tests.'
         amulet.raise_status(amulet.FAIL, msg=message)
        print('Output of netstat command id %s' % output)

if __name__ == '__main__':
    unittest.main()
